@@ -28,12 +28,7 @@ class Collection(object):
 	"""Represents a collection."""
 
 	def __init__(self, bus, collection_path=DEFAULT_COLLECTION, session=None):
-		try:
-			collection_obj = bus.get_object(SECRETS, collection_path)
-		except dbus.exceptions.DBusException as e:
-			if e.get_dbus_name() == DBUS_SERVICE_UNKNOWN:
-				raise SecretServiceNotAvailableException(e.get_dbus_message())
-			raise
+		collection_obj = bus_get_object(bus, SECRETS, collection_path)
 		self.bus = bus
 		self.session = session
 		self.collection_path = collection_path
@@ -43,7 +38,8 @@ class Collection(object):
 			dbus.PROPERTIES_IFACE)
 
 	def is_locked(self):
-		"""Returns ``True`` if item is locked, otherwise ``False``."""
+		"""Returns :const:`True` if item is locked, otherwise
+		:const:`False`."""
 		return bool(self.collection_props_iface.Get(
 			COLLECTION_IFACE, 'Locked'))
 
@@ -57,7 +53,8 @@ class Collection(object):
 		"""Requests unlocking the collection. If `callback` is specified,
 		calls it when unlocking is complete (see
 		:func:`~secretstorage.util.exec_prompt` description for
-		details). Otherwise, uses asynchronous loop from GLib API."""
+		details) and returns a boolean representing whether the operation was
+		dismissed. Otherwise, uses asynchronous loop from GLib API."""
 		service_obj = self.bus.get_object(SECRETS, SS_PATH)
 		service_iface = InterfaceWrapper(service_obj, SERVICE_IFACE)
 		prompt = service_iface.Unlock([self.collection_path], signature='ao')[1]
@@ -65,7 +62,7 @@ class Collection(object):
 			if callback:
 				exec_prompt(self.bus, prompt, callback)
 			else:
-				exec_prompt_async_glib(self.bus, prompt)
+				return exec_prompt_async_glib(self.bus, prompt)[0]
 		elif callback:
 			# We still need to call it.
 			callback(False, [])
@@ -79,7 +76,7 @@ class Collection(object):
 	def delete(self):
 		"""Deletes the collection and all items inside it."""
 		self.ensure_not_locked()
-		return self.collection_iface.Delete()
+		self.collection_iface.Delete()
 
 	def get_all_items(self):
 		"""Returns a generator of all items in the collection."""
@@ -90,8 +87,11 @@ class Collection(object):
 	def search_items(self, attributes):
 		"""Returns a generator of items with the given attributes.
 		`attributes` should be a dictionary."""
-		locked, unlocked = self.collection_iface.SearchItems(attributes)
-		for item_path in locked + unlocked:
+		result = self.collection_iface.SearchItems(attributes)
+		if isinstance(result, tuple):
+			# bug in GNOME Keyring <= 3.7.5
+			result = result[0] + result[1]
+		for item_path in result:
 			yield Item(self.bus, item_path, self.session)
 
 	def get_label(self):
@@ -104,15 +104,18 @@ class Collection(object):
 		self.ensure_not_locked()
 		self.collection_props_iface.Set(COLLECTION_IFACE, 'Label', label)
 
-	def create_item(self, label, attributes, secret, replace=False):
+	def create_item(self, label, attributes, secret, replace=False,
+	content_type='text/plain'):
 		"""Creates a new :class:`~secretstorage.item.Item` with given
 		`label` (unicode string), `attributes` (dictionary) and `secret`
-		(bytestring). If `replace` is ``True``, replaces the existing
-		item with the same attributes. Returns the created item."""
+		(bytestring). If `replace` is :const:`True`, replaces the existing
+		item with the same attributes. If `content_type` is given, also
+		sets the content type of the secret (``text/plain`` by default).
+		Returns the created item."""
 		self.ensure_not_locked()
 		if not self.session:
 			self.session = open_session(self.bus)
-		secret = format_secret(secret, self.session)
+		secret = format_secret(self.session, secret, content_type)
 		properties = {
 			SS_PREFIX+'Item.Label': label,
 			SS_PREFIX+'Item.Attributes': attributes
@@ -129,7 +132,7 @@ def create_collection(bus, label, alias='', session=None):
 	if not session:
 		session = open_session(bus)
 	properties = {SS_PREFIX+'Collection.Label': label}
-	service_obj = bus.get_object(SECRETS, SS_PATH)
+	service_obj = bus_get_object(bus, SECRETS, SS_PATH)
 	service_iface = dbus.Interface(service_obj, SERVICE_IFACE)
 	collection_path, prompt = service_iface.CreateCollection(properties,
 		alias)
@@ -139,3 +142,32 @@ def create_collection(bus, label, alias='', session=None):
 	if dismissed:
 		raise ItemNotFoundException('Prompt dismissed.')
 	return Collection(bus, unlocked, session=session)
+
+def get_all_collections(bus):
+	"""Returns a generator of all available collections."""
+	service_obj = bus_get_object(bus, SECRETS, SS_PATH)
+	service_props_iface = dbus.Interface(service_obj,
+		dbus.PROPERTIES_IFACE)
+	for collection_path in service_props_iface.Get(SERVICE_IFACE,
+	'Collections'):
+		yield Collection(bus, collection_path)
+
+def get_collection_by_alias(bus, alias):
+	"""Returns the collection with alias `alias`. If there is no such
+	collection, raises
+	:exc:`~secretstorage.exceptions.ItemNotFoundException`."""
+	service_obj = bus_get_object(bus, SECRETS, SS_PATH)
+	service_iface = dbus.Interface(service_obj, SERVICE_IFACE)
+	collection_path = service_iface.ReadAlias(alias)
+	if len(collection_path) <= 1:
+		raise ItemNotFoundException('No collection with such alias.')
+	return Collection(bus, collection_path)
+
+def search_items(bus, attributes):
+	"""Returns a generator of items in all collections with the given
+	attributes. `attributes` should be a dictionary."""
+	service_obj = bus_get_object(bus, SECRETS, SS_PATH)
+	service_iface = dbus.Interface(service_obj, SERVICE_IFACE)
+	locked, unlocked = service_iface.SearchItems(attributes)
+	for item_path in locked + unlocked:
+		yield Item(bus, item_path)
