@@ -9,12 +9,12 @@ something goes wrong. All exceptions derive from base
 
 class SecretStorageException(Exception):
 	"""All exceptions derive from this class."""
-	pass
 
 class SecretServiceNotAvailableException(Exception):
-	"""Raised by :class:`~secretstorage.collection.Collection` or
-	:class:`~secretstorage.item.Item` constructors when the Secret Service
-	API is not available."""
+	"""Raised by :class:`~secretstorage.item.Item` or
+	:class:`~secretstorage.collection.Collection` constructors, or by
+	other functions in the :mod:`secretstorage.collection` module, when
+	the Secret Service API is not available."""
 
 class LockedException(SecretStorageException):
 	"""Raised when an action cannot be performed because the collection
@@ -22,7 +22,6 @@ class LockedException(SecretStorageException):
 	to check if the collection is locked, and
 	:meth:`~secretstorage.collection.Collection.unlock` to unlock it.
 	"""
-	pass
 
 class ItemNotFoundException(SecretStorageException):
 	"""Raised when an item does not exist or has been deleted. Example of
@@ -39,4 +38,3 @@ class ItemNotFoundException(SecretStorageException):
 	this exception when a prompt was dismissed during creating the
 	collection.
 	"""
-	pass
