@@ -5,7 +5,8 @@
 # This file tests the secretstorage.Collection class.
 
 import unittest
-from secretstorage import dbus_init, Collection, Item
+import time
+from secretstorage import dbus_init, search_items, Collection
 
 ATTRIBUTES = {'application': 'secretstorage-test', 'attribute': 'qwerty'}
 NEW_ATTRIBUTES = {'application': 'secretstorage-test',
@@ -15,13 +16,14 @@ class ItemTest(unittest.TestCase):
 	"""A test case that tests that all common methods of Item
 	class work and do not crash."""
 
-	def setUp(self):
-		bus = dbus_init(main_loop=False)
-		self.collection = Collection(bus)
-		self.item = self.collection.create_item('My item', ATTRIBUTES,
+	@classmethod
+	def setUpClass(cls):
+		cls.bus = dbus_init(main_loop=False)
+		cls.collection = Collection(cls.bus)
+		cls.item = cls.collection.create_item('My item', ATTRIBUTES,
 			b'pa$$word')
-		self.other_item = self.collection.create_item('My item',
-			ATTRIBUTES, b'')
+		cls.other_item = cls.collection.create_item('My item',
+			ATTRIBUTES, '', content_type='data/null')
 
 	def test_equal(self):
 		self.assertEqual(self.item, self.item)
@@ -30,19 +32,13 @@ class ItemTest(unittest.TestCase):
 
 	def test_searchable(self):
 		search_results = self.collection.search_items(ATTRIBUTES)
-		found = False
-		for item in search_results:
-			if item == self.item:
-				found = True
-		self.assertTrue(found)
+		self.assertIn(self.item, search_results)
+		search_results = search_items(self.bus, ATTRIBUTES)
+		self.assertIn(self.item, search_results)
 
 	def test_item_in_all_items(self):
 		all_items = self.collection.get_all_items()
-		found = False
-		for item in all_items:
-			if item == self.item:
-				found = True
-		self.assertTrue(found)
+		self.assertIn(self.item, all_items)
 
 	def test_attributes(self):
 		attributes = self.item.get_attributes()
@@ -63,10 +59,26 @@ class ItemTest(unittest.TestCase):
 		self.assertEqual(self.item.get_secret(), b'pa$$word')
 		self.item.set_secret(b'newpa$$word')
 		self.assertEqual(self.item.get_secret(), b'newpa$$word')
+		self.assertEqual(self.other_item.get_secret(), b'')
 
-	def tearDown(self):
-		self.item.delete()
-		self.other_item.delete()
+	def test_secret_content_type(self):
+		self.assertEqual(self.item.get_secret_content_type(), 'text/plain')
+		# The check below fails in gnome-keyring because it doesn't really
+		# support content types.
+		#self.assertEqual(self.other_item.get_secret_content_type(), 'data/null')
+
+	def test_modified(self):
+		now = time.time()
+		modified = self.item.get_modified()
+		self.assertAlmostEqual(now, modified, places=-1)
+
+	@classmethod
+	def tearDownClass(cls):
+		cls.item.delete()
+		cls.other_item.delete()
+
+if not hasattr(ItemTest, 'assertIn'): # Python <= 2.6
+	ItemTest.assertIn = lambda self, a, b: self.assertTrue(a in b)
 
 if __name__ == '__main__':
 	unittest.main()
